==> xcfa_3.4.9.orig.tar.gz: xcfa-3.4.9/src/global.h <==
 /*
 * file      : global.h
 * project   : xcfa
 * with      : Gtk-2
 *
 * copyright : (C) 2003,2004,2005,2006,2007,2008,2009 by Claude Bulin
 *
 * xcfa - GTK+ implementation of the GNU shell command
 * GNU General Public License
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * OLD ADRESS:
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 * NEW ADRESS:
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 * 
 */


#ifndef __global_h__
#define __global_h__ 1


extern GtkWidget *wind_main;
void segfault_handler_mess_error (gchar *p_mess);

/*
PRINTBOOL("var_cd.BoolCreateFileCueFromCD", var_cd.BoolCreateFileCueFromCD);
*/


/*
*---------------------------------------------------------------------------
* DEBUG
*---------------------------------------------------------------------------
*/
#define PRINTINT(str,num) g_print ("%s = %d\n", str, num)
#define PRINTBOOL(str,bool) g_print ("%s = %s\n", str, bool == TRUE ? "TRUE" : "FALSE")
#define PRINT_FUNC_LF() g_print ("%s :: %s (line = %d) \n", __FILE__, __FUNCTION__, __LINE__)
#define PRINT(str) g_print ("%s -:- %s(%d)\n\t%s\n", __FILE__, __FUNCTION__, __LINE__, str)

/*
*---------------------------------------------------------------------------
* SUPPORT
*---------------------------------------------------------------------------
*/
#ifndef GLADE_HOOKUP_OBJECT
#define GLADE_HOOKUP_OBJECT(component,widget,name) \
  g_object_set_data_full (G_OBJECT (component), name, \
    gtk_widget_ref (widget), (GDestroyNotify) gtk_widget_unref)
#endif

#ifndef GLADE_HOOKUP_OBJECT_NO_REF
#define GLADE_HOOKUP_OBJECT_NO_REF(component,widget,name) \
  g_object_set_data (G_OBJECT (component), name, widget)
#endif


/*
*---------------------------------------------------------------------------
* TEMPS
*---------------------------------------------------------------------------
*/
#define GETTIMESEC(H,M,S,C) (gdouble)((H * 60) * 60) + (gdouble)(M * 60) + (gdouble)S + (gdouble)(C / 100.0)
#define GETTIMEPERCENT(SecondesTempsActuel,AllTime) ((gdouble)SecondesTempsActuel / (gdouble)AllTime) * 100.0

/*
*---------------------------------------------------------------------------
* NOTEBOOK
*---------------------------------------------------------------------------
*/

#define NOTEBOOK_DVD_AUDIO	0
#define NOTEBOOK_CD_AUDIO	1
	#define NOTEBOOK_CD_AUDIO_TAGS		0
	#define NOTEBOOK_CD_AUDIO_TITRE_CD	1
	#define NOTEBOOK_CD_AUDIO_CUE		2
#define NOTEBOOK_FICHIERS	2
	#define NOTEBOOK_FICHIERS_CONVERSION	0
	#define NOTEBOOK_FICHIERS_WAV		1
	#define NOTEBOOK_FICHIERS_MP3OGG	2
	#define NOTEBOOK_FICHIERS_TAGS		3
#define NOTEBOOK_SPLIT		3
#define NOTEBOOK_POCHETTE	4
	#define NOTEBOOK_POCHETTE_IMAGE		0
	#define NOTEBOOK_POCHETTE_TITRE		1
	#define NOTEBOOK_POCHETTE_TEXTE		2
#define NOTEBOOK_LOGS		5
	#define NOTEBOOK_LOGS_COMPUTER		0
	#define NOTEBOOK_LOGS_FILE_IMPORT	1
#define NOTEBOOK_OPTIONS	6
	#define NOTEBOOK_OPTIONS_GENERAL	0
	#define NOTEBOOK_OPTIONS_CD_AUDIO	1
	#define NOTEBOOK_OPTIONS_LAME		2
	#define NOTEBOOK_OPTIONS_OGGENC		3
	#define NOTEBOOK_OPTIONS_FLAC		4
	#define NOTEBOOK_OPTIONS_MAC		5
	#define NOTEBOOK_OPTIONS_WAVPACK	6
	#define NOTEBOOK_OPTIONS_MUSEPACK	7
	#define NOTEBOOK_OPTIONS_FAAC		8
	#define NOTEBOOK_OPTIONS_AACPLUSENC	9
	#define NOTEBOOK_OPTIONS_EXPORT_TAGS	10
#define NOTEBOOK_PRGEXTERNES	7
	#define NOTEBOOK_OPTIONS_PRGEXTERNES	0
		#define NOTEBOOK_OPTIONS_TYPE_DEB	0
		#define NOTEBOOK_OPTIONS_TYPE_OTHER	1
	#define NOTEBOOK_OPTIONS_PRGNAVIGATOR	1
	#define NOTEBOOK_OPTIONS_PRGPOSTSCRIPT	2
	#define NOTEBOOK_OPTIONS_PRGAUDIO	3



/* Taille des caracteres dans la Statusbarre
*/
#define SIZE_CAR_STATUSBAR 9

/*
GDK_NOTHING		a special code to indicate a null event.
GDK_KEY_PRESS		a key has been pressed.
GDK_KEY_RELEASE		a key has been released.
*/
typedef struct {
	gint		eventkey;		/* GDK_NOTHING | GDK_KEY_PRESS | GDK_KEY_RELEASE	*/
	gint		type;			/* GdkEventType						*/
	guint		state;			/*							*/
	guint		keyval;			/*							*/
	guint16		hardware_keycode;	/*							*/
	gchar		str [ 2 ];		/*							*/
/*
#define GDK_KP_Add 0xffab
#define GDK_KP_Subtract 0xffad
#define GDK_plus 0x02b
#define GDK_minus 0x02d
*/
	gboolean	BoolGDK_KP_Add;		/*							*/
	gboolean	BoolGDK_KP_Subtract;	/*							*/
	gboolean	BoolGDK_plus;		/*							*/
	gboolean	BoolGDK_minus;		/*							*/
/*
#define GDK_Control_L 0xffe3
#define GDK_Control_R 0xffe4
*/
	gboolean	BoolGDK_Control_L;	/* TRUE is PRESS else is RELEASE			*/
	gboolean	BoolGDK_Control_R;	/* TRUE is PRESS else is RELEASE			*/
/*
#define GDK_Shift_L 0xffe1
#define GDK_Shift_R 0xffe2
*/
	gboolean	BoolGDK_Shift_L;	/* TRUE is PRESS else is RELEASE			*/
	gboolean	BoolGDK_Shift_R;	/* TRUE is PRESS else is RELEASE			*/
/*
#define GDK_Left 0xff51
#define GDK_Right 0xff53
*/
	gboolean	BoolGDK_Left;		/* TRUE is PRESS else is RELEASE			*/
	gboolean	BoolGDK_Right;		/* TRUE is PRESS else is RELEASE			*/
	
	gboolean	BoolGDK_Control_A;	/* TRUE is PRESS else is RELEASE			*/
} KEYS;

extern KEYS keys;


typedef struct {
	gchar      Machine [ 100 ];
	gint       NbCpu;
	gint       TypeCpu;
	gboolean   BoolCpuIs64Bits;
	
} HOST_CONF;

extern HOST_CONF HostConf;


/*
*---------------------------------------------------------------------------
* Dossier temporaire
*---------------------------------------------------------------------------
*/

#define PATH_TMP_XCFA_SPLIT "xcfa_split"

#define PATH_TMP_XCFA_SHNSPLIT "xcfa_shnsplit"

#define PATH_TMP_XCFA_AUDIOCD "xcfa_cdaudio"

#define PATH_TMP_XCFA_AUDIOFILE "xcfa_audiofile"

#define PATH_TMP_XCFA_AUDIOFILEWAVCONV "xcfa_audiofilewavconv"

#define PATH_TMP_XCFA_AUDIOFILEMP3OGG "xcfa_audiofilemp3ogg"

#define PATH_TMP_XCFA_AUDIOFILENORMALYSE "xcfa_audiofilenormalyse"

#define PATH_TMP_XCFA_CDDBTEST "xcfa_cddbtest"

#define TMP_FILE_XCFA_INSTALL	"/tmp/tmp_file_xcfa_install.txt"
#define FILE_XCFA_INSTALL	"/tmp/xcfa_install.sh"
#define PATH_DOWNLOAD_TO_XCFA	"/tmp/download_to_xcfa"

#define PATH_SAVE_POCHETTE_IMG "XcfaPochette"
#define PATH_SAVE_POCHETTE_PS  "XcfaPochette/PostScript"
#define PATH_SAVE_POCHETTE_PNG "XcfaPochette/png"

#endif

==> xcfa_3.7.3.orig.tar.gz: xcfa-3.7.3/src/global.h <==
 /*
 * file      : global.h
 * project   : xcfa
 * with      : Gtk-2
 *
 * copyright : (C) 2003 - 2010 by Claude Bulin
 *
 * xcfa - GTK+ implementation of the GNU shell command
 * GNU General Public License
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * OLD ADRESS:
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 * NEW ADRESS:
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 * 
 */


#ifndef __global_h__
#define __global_h__ 1

#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gi18n.h>



void	segfault_handler_mess_error (gchar *p_mess);

extern	GtkBuilder	*GtkBuilderXcfa;


typedef struct {
	GtkWidget	*AdrWin;
	gboolean	 Bool;
} WIND_MAIN;

extern WIND_MAIN wind_main;

extern gboolean BoolWindErrorActivate;

#define XCFA_GET_OBJECT(OBJ) gtk_builder_get_object (GtkBuilderXcfa, OBJ)


/*
*---------------------------------------------------------------------------
* DEBUG
*---------------------------------------------------------------------------
*/
#define PRINTINT(str,num) g_print ("%s = %d\n", str, num)
#define PRINTBOOL(str,bool) g_print ("%s = %s\n", str, bool == TRUE ? "TRUE" : "FALSE")
#define PRINT_FUNC_LF() g_print ("%s :: %s (line = %d) \n", __FILE__, __FUNCTION__, __LINE__)
#define PRINT(str) g_print ("%s -:- %s(line = %d)\n\t%s\n", __FILE__, __FUNCTION__, __LINE__, str)

/*
*---------------------------------------------------------------------------
* SUPPORT
*---------------------------------------------------------------------------
*/
#ifndef GLADE_HOOKUP_OBJECT
#define GLADE_HOOKUP_OBJECT(component,widget,name) \
  g_object_set_data_full (G_OBJECT (component), name, \
    gtk_widget_ref (widget), (GDestroyNotify) gtk_widget_unref)
#endif

#ifndef GLADE_HOOKUP_OBJECT_NO_REF
#define GLADE_HOOKUP_OBJECT_NO_REF(component,widget,name) \
  g_object_set_data (G_OBJECT (component), name, widget)
#endif

/*
 * Standard gettext macros.
 */
/*
#ifdef ENABLE_NLS
#  include <libintl.h>
#  undef _
#  define _(String) dgettext (PACKAGE, String)
#  define Q_(String) g_strip_context ((String), gettext (String))
#  ifdef gettext_noop
#    define N_(String) gettext_noop (String)
#  else
#    define N_(String) (String)
#  endif
#else
#  define textdomain(String) (String)
#  define gettext(String) (String)
#  define dgettext(Domain,Message) (Message)
#  define dcgettext(Domain,Message,Type) (Message)
#  define bindtextdomain(Domain,Directory) (Domain)
#  define _(String) (String)
#  define Q_(String) g_strip_context ((String), (String))
#  define N_(String) (String)
#endif
*/

/* Use this function to set the directory containing installed pixmaps. */
void add_pixmap_directory (const gchar *directory);
/* This is used to create the pixmaps used in the interface. */
GtkWidget *create_pixmap (GtkWidget *widget, const gchar *filename);

/*
*---------------------------------------------------------------------------
* TEMPS
*---------------------------------------------------------------------------
*/
#define GETTIMESEC(H,M,S,C) (gdouble)((H * 60) * 60) + (gdouble)(M * 60) + (gdouble)S + (gdouble)(C / 100.0)
#define GETTIMEPERCENT(SecondesTempsActuel,AllTime) ((gdouble)SecondesTempsActuel / (gdouble)AllTime) * 100.0

/*
*---------------------------------------------------------------------------
* NOTEBOOK
*---------------------------------------------------------------------------
*/

#define NOTEBOOK_DVD_AUDIO	0
#define NOTEBOOK_CD_AUDIO	1
	#define NOTEBOOK_CD_AUDIO_TAGS		0
	#define NOTEBOOK_CD_AUDIO_TITRE_CD	1
	#define NOTEBOOK_CD_AUDIO_CUE		2
#define NOTEBOOK_FICHIERS	2
	#define NOTEBOOK_FICHIERS_CONVERSION	0
	#define NOTEBOOK_FICHIERS_WAV		1
	#define NOTEBOOK_FICHIERS_MP3OGG	2
	#define NOTEBOOK_FICHIERS_TAGS		3
#define NOTEBOOK_SPLIT		3
#define NOTEBOOK_POCHETTE	4
	#define NOTEBOOK_POCHETTE_IMAGE		0
	#define NOTEBOOK_POCHETTE_TITRE		1
	#define NOTEBOOK_POCHETTE_TEXTE		2
#define NOTEBOOK_OPTIONS	5
	#define NOTEBOOK_OPTIONS_GENERAL	0
	#define NOTEBOOK_OPTIONS_CD_AUDIO	1
	#define NOTEBOOK_OPTIONS_LAME		2
	#define NOTEBOOK_OPTIONS_OGGENC		3
	#define NOTEBOOK_OPTIONS_FLAC		4
	#define NOTEBOOK_OPTIONS_MAC		5
	#define NOTEBOOK_OPTIONS_WAVPACK	6
	#define NOTEBOOK_OPTIONS_MUSEPACK	7
	#define NOTEBOOK_OPTIONS_FAAC		8
	#define NOTEBOOK_OPTIONS_AACPLUSENC	9
	#define NOTEBOOK_OPTIONS_EXPORT_TAGS	10
#define NOTEBOOK_PRGEXTERNES	6
	#define NOTEBOOK_OPTIONS_PRGEXTERNES	0
	#define NOTEBOOK_OPTIONS_PRGNAVIGATOR	1
	#define NOTEBOOK_OPTIONS_PRGPOSTSCRIPT	2
	#define NOTEBOOK_OPTIONS_PRGAUDIO	3



/* Taille des caracteres dans la Statusbarre
*/
#define SIZE_CAR_STATUSBAR 9

/*
GDK_NOTHING		a special code to indicate a null event.
GDK_KEY_PRESS		a key has been pressed.
GDK_KEY_RELEASE		a key has been released.
*/
typedef struct {
	gint		eventkey;		/* GDK_NOTHING | GDK_KEY_PRESS | GDK_KEY_RELEASE	*/
	gint		type;			/* GdkEventType						*/
	guint		state;			/*							*/
	guint		keyval;			/*							*/
	guint16		hardware_keycode;	/*							*/
	gchar		str [ 2 ];		/*							*/
/*
#define GDK_KP_Add 0xffab
#define GDK_KP_Subtract 0xffad
#define GDK_plus 0x02b
#define GDK_minus 0x02d
*/
	gboolean	BoolGDK_KP_Add;		/*							*/
	gboolean	BoolGDK_KP_Subtract;	/*							*/
	gboolean	BoolGDK_plus;		/*							*/
	gboolean	BoolGDK_minus;		/*							*/
/*
#define GDK_Control_L 0xffe3
#define GDK_Control_R 0xffe4
*/
	gboolean	BoolGDK_Control_L;	/* TRUE is PRESS else is RELEASE			*/
	gboolean	BoolGDK_Control_R;	/* TRUE is PRESS else is RELEASE			*/
/*
#define GDK_Shift_L 0xffe1
#define GDK_Shift_R 0xffe2
*/
	gboolean	BoolGDK_Shift_L;	/* TRUE is PRESS else is RELEASE			*/
	gboolean	BoolGDK_Shift_R;	/* TRUE is PRESS else is RELEASE			*/
/*
#define GDK_Left 0xff51
#define GDK_Right 0xff53
*/
	gboolean	BoolGDK_Left;		/* TRUE is PRESS else is RELEASE			*/
	gboolean	BoolGDK_Right;		/* TRUE is PRESS else is RELEASE			*/
	
	gboolean	BoolGDK_Control_A;	/* TRUE is PRESS else is RELEASE			*/
} KEYS;

extern KEYS keys;


typedef struct {
	gchar      Machine [ 100 ];
	gint       NbCpu;
	gint       TypeCpu;
	gboolean   BoolCpuIs64Bits;
	
} HOST_CONF;

extern HOST_CONF HostConf;




/*
*---------------------------------------------------------------------------
* Dossier temporaire
*---------------------------------------------------------------------------
*/

#define PATH_TMP_XCFA_CD_NORMALISE_PEAK_ALBUM "xcfa_peak_album"
#define PATH_TMP_XCFA_SPLIT "xcfa_split"

#define PATH_TMP_XCFA_SHNSPLIT "xcfa_shnsplit"

#define PATH_TMP_XCFA_AUDIOCD "xcfa_cdaudio"

#define PATH_TMP_XCFA_AUDIOFILE "xcfa_audiofile"

#define PATH_TMP_XCFA_AUDIOFILEWAVCONV "xcfa_audiofilewavconv"

#define PATH_TMP_XCFA_AUDIOFILEMP3OGG "xcfa_audiofilemp3ogg"

#define PATH_TMP_XCFA_AUDIOFILENORMALYSE "xcfa_audiofilenormalyse"

#define PATH_TMP_XCFA_CDDBTEST "xcfa_cddbtest"

#define TMP_FILE_XCFA_INSTALL	"/tmp/tmp_file_xcfa_install.txt"
#define FILE_XCFA_INSTALL	"/tmp/xcfa_install.sh"
#define PATH_DOWNLOAD_TO_XCFA	"/tmp/download_to_xcfa"

#define PATH_SAVE_POCHETTE_IMG "XcfaPochette"
#define PATH_SAVE_POCHETTE_PS  "XcfaPochette/PostScript"
#define PATH_SAVE_POCHETTE_PNG "XcfaPochette/png"

#define PATH_MANPAGE "XcfaManpage"

#define PATH_TMP_XCFA_ICEDAX "XcfaIcedax"

#endif
